social-media plugin for `Grvlms <https://docs.grvlms.overhang.io>`__
===================================================================================

Installation
------------

::

    pip install git+https://github.com/groovetch/grvlms-social-media

Usage
-----

::

    grvlms plugins enable socialmedia
    grvlms socialmedia config -i (Run command in interactive mode)
    grvlms local start

License
-------

This software is licensed under the terms of the AGPLv3.